import Typography from "@/shared/ui/components/Typography/Typography";
import "./Statistics.scss";
import { apiInstance } from "@/shared/config/apiConfig";
import { IStatistics } from "@/shared/types/statistics-type";
import { AxiosError } from "axios";
import StatisticsTable from "@/widgets/StatisticsTable/StatisticsTable";

const Statistics = async () => {
  const getStatistics = async (): Promise<IStatistics[] | string> => {
    try {
      const response = await apiInstance.get<IStatistics[]>(
        "/report/city/stats/"
      );

      return response.data;
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        return error.message;
      } else {
        return "Произошла непредвиденная ошибк";
      }
    }
  };

  const data = await getStatistics();
  return (
    <div className="statistics page-padding">
      <Typography element="h2">Статистика</Typography>
      <StatisticsTable firstData={data} />
    </div>
  );
};

export default Statistics;
