"use client";

import "./HomeMap.scss";
import "leaflet/dist/leaflet.css";
import {
  MapContainer,
  Marker,
  Popup,
  TileLayer,
  useMap,
} from "react-leaflet";
import geo_green_icon from "./icons/geo-green.svg";
import geo_orange_icon from "./icons/geo-orange.svg";
import geo_pink_icon from "./icons/geo-pink.svg";
import geo_purple_icon from "./icons/geo-purple.svg";
import geo_red_icon from "./icons/geo-red.svg";
import geo_yellow_icon from "./icons/geo-yellow.svg";
import { DivIcon, Icon, LatLngTuple } from "leaflet";
import { StaticImageData } from "next/image";
import Link from "next/link";
import { useEffect, useState } from "react";
import L from "leaflet";
import { ILocation } from "@/shared/types/location-type";

interface IData {
  id: number;
  location: ILocation[];
  category: number;
}

interface ILatLng {
  lat: number;
  lng: number;
}

interface IHomeMapProps {
  data: IData[] | undefined;
  latLng: ILatLng;
}

const HomeMap: React.FC<IHomeMapProps> = ({
  data,
  latLng,
}: IHomeMapProps) => {
  const [position, setPosition] = useState<ILatLng>({
    lat: 42.8746,
    lng: 74.606,
  });
  const createCustomIcon = (icon: StaticImageData) => {
    const customIcon = new Icon({
      iconUrl: icon.src,
      iconSize: [32, 32],
    });

    return customIcon;
  };

  const icons: Record<string, DivIcon> = {
    1: createCustomIcon(geo_red_icon),
    2: createCustomIcon(geo_pink_icon),
    3: createCustomIcon(geo_purple_icon),
    4: createCustomIcon(geo_orange_icon),
    5: createCustomIcon(geo_green_icon),
    6: createCustomIcon(geo_yellow_icon),
  };

  const LocationMark = () => {
    const map = useMap();

    map.setView(L.latLng(latLng), map.getZoom(), { animate: true });

    useEffect(() => {
      setPosition(latLng);
    }, [latLng]);

    return null;
  };

  return (
    <MapContainer
      center={position}
      zoom={14}
      scrollWheelZoom={false}
      className="home-map"
    >
      <TileLayer
        attribution='&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
        url="https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
      />
      {data?.map((marker) => (
        <Marker
          key={marker.id}
          icon={icons[marker.category]}
          position={
            [
              +marker.location[0].latitude,
              +marker.location[0].longitude,
            ] as LatLngTuple
          }
        >
          <Popup>
            <Link href={`/report/${marker.location[0].id}`}>
              {marker.location[0].address}
            </Link>
          </Popup>
        </Marker>
      ))}
      <LocationMark />
    </MapContainer>
  );
};

export default HomeMap;
