import { apiInstance } from "@/shared/config/apiConfig";
import { IFetch } from "@/shared/types/fetch-type";
import { IList } from "@/shared/types/list-type";
import { IDisplayMap } from "@/shared/types/map-type";
import { IReport } from "@/shared/types/report-type";
import axios from "axios";
import { create } from "zustand";

interface IFetchReports extends IList {
  results: IReport[];
}

interface IMapStore extends IFetch {
  data: IFetchReports;
  searchData: IDisplayMap[];
  getReports: (categories: string) => Promise<void>;
  getLocations: (query: string) => void;
}

export const useMapStore = create<IMapStore>((set) => ({
  data: {
    count: 0,
    previous: null,
    next: null,
    results: [],
  },
  searchData: [],
  isLoading: false,
  error: "",
  getReports: async (categories: string = "1,2,3,4,5,6") => {
    try {
      set({ isLoading: true });

      const response = await apiInstance.get<IFetchReports>(
        `/report/?category=${categories}`
      );

      set({ data: response.data });
    } catch (error: any) {
      set({ error: error.message });
    } finally {
      set({ isLoading: false });
    }
  },
  getLocations: async (query: string = "") => {
    const params: Record<string, any> = {
      q: query,
      format: "json",
      addressdetails: 1,
      polygon_geojson: 0,
    };
    const queryString = new URLSearchParams(params).toString();
    const url = `https://nominatim.openstreetmap.org/search?${queryString}`;

    const response = await axios.get<IDisplayMap[]>(url);

    const inKG = response.data.filter((location) => {
      return location.address.country_code.toLowerCase() === "kg";
    });

    set({ searchData: inKG });
  },
}));
