"use client";

import { IStatistics } from "@/shared/types/statistics-type";
import "./StatisticsTable.scss";
import { useStatisticsStore } from "./statistics.store";
import { useShallow } from "zustand/react/shallow";
import SearchForm from "@/features/SearchForm/SearchForm";
import chevron_down from "./icons/chevron-down.svg";
import arrows from "@/shared/icons/arrows.svg";

import Image from "next/image";
import { useEffect, useState } from "react";

interface IStatisticsTableProps {
  firstData: IStatistics[] | string;
}

const StatisticsTable: React.FC<IStatisticsTableProps> = ({
  firstData,
}: IStatisticsTableProps) => {
  const { data, error, isLoading, getStatistics } =
    useStatisticsStore(useShallow((state) => state));

  const [statistics, setStatistics] = useState<IStatistics[]>(
    typeof firstData === "string" ? [] : firstData
  );
  const [openPopup, setOpenPopup] = useState<boolean>(false);

  const handleSubmit = () => {};

  const params = [
    { param: "Добавлено дорог", handleSubmit() {} },
    { param: "Локальных дефектов", handleSubmit() {} },
    { param: "Очагов аварийности", handleSubmit() {} },
    { param: "Локальных дефектов исправлено", handleSubmit() {} },
    { param: "В планах ремонта", handleSubmit() {} },
    { param: "Отремонтировано", handleSubmit() {} },
  ];

  const getStatsByLocation = async (location: string) => {
    try {
      const data: IStatistics[] | undefined = await getStatistics(
        location
      );

      if (data === undefined)
        throw new Error("Ошибка на стороне сервера");
      setStatistics(data);
    } catch (error) {
      console.error("Error fetching statistics:", error);
    }
  };

  return (
    <div className="statistics-table">
      <SearchForm
        style={{ width: "100%" }}
        handleSubmit={handleSubmit}
      />

      {openPopup && (
        <div className="statistics-table__popup">
          <button onClick={() => getStatsByLocation("state")}>
            Область
          </button>
          <button onClick={() => getStatsByLocation("city")}>
            Город
          </button>
          <button onClick={() => getStatsByLocation("village")}>
            Деревня
          </button>
        </div>
      )}

      <div className="statistics-table__wrapper">
        <table>
          <thead>
            <tr>
              <td>
                <button onClick={() => setOpenPopup((prev) => !prev)}>
                  Город
                  <Image src={chevron_down} alt=" Chevron Icon" />
                </button>
              </td>
              {params.map((param) => (
                <td key={param.param}>
                  <button>
                    {param.param}
                    <Image src={arrows} alt=" Arrows Icon" />
                  </button>
                </td>
              ))}
            </tr>
          </thead>
          <tbody>
            {statistics.map((stat) => (
              <tr key={stat.name}>
                <td id="statistics-table-stat-name">{stat.name}</td>
                <td>{stat.broken_road_1}</td>
                <td>{stat.local_defect_3}</td>
                <td>{stat.hotbed_of_accidents_2}</td>
                <td>{stat.local_defect_fixed_6}</td>
                <td>{stat.repair_plans_4}</td>
                <td>{stat.repaired_5}</td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    </div>
  );
};

export default StatisticsTable;
