import { apiInstance } from "@/shared/config/apiConfig";
import { IFetch } from "@/shared/types/fetch-type";
import { IStatistics } from "@/shared/types/statistics-type";
import { AxiosError } from "axios";
import { create } from "zustand";

interface IStatisticsStore extends IFetch {
  getStatistics: (
    endpoint: string
  ) => Promise<IStatistics[] | undefined>;
}

export const useStatisticsStore = create<IStatisticsStore>((set) => ({
  isLoading: false,
  error: "",

  getStatistics: async (
    endpoint: string
  ): Promise<IStatistics[] | undefined> => {
    try {
      set({ isLoading: true });
      const response = await apiInstance.get<IStatistics[]>(
        `/report/${endpoint}/stats`
      );

      return response.data;
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        set({ error: error.message });
      } else {
        set({ error: "an error ocured" });
      }
    } finally {
      set({ isLoading: false });
    }
  },
}));
